import request from '@/utils/request'

// 后台账号列表
export function dispatchAccountL(query) {
    return request({
        url: '/user/l',
        method: 'get',
        params: query
    })
}

// 注册用户
export function dispatchAccountC(data){
    return request({
        url: '/user/c',
        method: 'post',
        data: data
    })
}

//编辑员工账号
export function dispatchAccountU(data){
    return request({
        url: '/user/u',
        method: 'post',
        data: data
    })
}


// 员工账号-重置密码
export function dispatchResetPwd(data) {
    return request({
        url: '/user/reset',
        method: 'post',
        data: data
    })
}

// 员工账号-修改状态
export function dispatchStateU(data) {
    return request({
        url: '/user/ustate',
        method: 'post',
        data: data
    })
}
// 删除用户
export function userDelete(data) {
    return request({
        url: '/user/d',
        method: 'post',
        data: data
    })
}

// 修改当前登录账号密码
export function editPayPassword(data) {
    return request({
        url: '/user/u/password',
        method: 'post',
        data: data
    })
}